summaryrefslogtreecommitdiffstats
path: root/kivio/plugins/kiviosmlconnector
diff options
context:
space:
mode:
Diffstat (limited to 'kivio/plugins/kiviosmlconnector')
-rw-r--r--kivio/plugins/kiviosmlconnector/sml_connector/sml_connector.cpp16
-rw-r--r--kivio/plugins/kiviosmlconnector/sml_connector/sml_connector.h2
-rw-r--r--kivio/plugins/kiviosmlconnector/tool_connector.cpp4
3 files changed, 11 insertions, 11 deletions
diff --git a/kivio/plugins/kiviosmlconnector/sml_connector/sml_connector.h b/kivio/plugins/kiviosmlconnector/sml_connector/sml_connector.h
index b631f84b..a50ec750 100644
--- a/kivio/plugins/kiviosmlconnector/sml_connector/sml_connector.h
+++ b/kivio/plugins/kiviosmlconnector/sml_connector/sml_connector.h
@@ -43,7 +43,7 @@ class KivioSMLConnector : public Kivio1DStencil
private:
bool loadPath(const TQString &file);
//void drawOpenPath( KivioShape *, KivioIntraStencilData * );
- KivioShape *m_shape;
+ KivioShape *m_tqshape;
TQPtrList<KivioConnectorPoint> m_PointList;
TQString m_name;
diff --git a/kivio/plugins/kiviosmlconnector/tool_connector.cpp b/kivio/plugins/kiviosmlconnector/tool_connector.cpp
index 5cef094e..4578f0a7 100644
--- a/kivio/plugins/kiviosmlconnector/tool_connector.cpp
+++ b/kivio/plugins/kiviosmlconnector/tool_connector.cpp
@@ -190,7 +190,7 @@ bool SMLConnector::startRubberBanding( TQMouseEvent *e )
m_pStencil->customDrag(m_pDragData);
- canvas->repaint();
+ canvas->tqrepaint();
canvas->setCursor(*m_pConnectorCursor2);
return true;
}
@@ -223,7 +223,7 @@ void SMLConnector::continueRubberBanding( TQMouseEvent *e )
m_pStencil->customDrag(m_pDragData);
m_pStencil->updateGeometry();
- canvas->repaint();
+ canvas->tqrepaint();
}
void SMLConnector::mouseRelease( TQMouseEvent *e )
diff --git a/kivio/plugins/kiviosmlconnector/sml_connector/sml_connector.cpp b/kivio/plugins/kiviosmlconnector/sml_connector/sml_connector.cpp
index 8617eb98..3745820c 100644
--- a/kivio/plugins/kiviosmlconnector/sml_connector/sml_connector.cpp
+++ b/kivio/plugins/kiviosmlconnector/sml_connector/sml_connector.cpp
@@ -32,7 +32,7 @@
#include "kivio_stencil_spawner_set.h"
#include "kivio_text_style.h"
#include "kivio_shape.h"
-#include "kivio_shape_data.h"
+#include "kivio_tqshape_data.h"
#include "kivio_point.h"
#include "tkmath.h"
@@ -96,9 +96,9 @@ KivioSMLConnector::KivioSMLConnector( const TQString &name )
// This is a stencil of type connector
setType( kstConnector );
// We only have one shape, an open path.
//m_shape = new KivioShape();
//m_shape->shapeData() ->setShapeType( KivioShapeData::kstOpenPath );
loadPath( name );
}
@@ -196,7 +196,7 @@ KivioStencil *KivioSMLConnector::duplicate()
void KivioSMLConnector::drawOpenPath( KivioShape *pShape, KivioIntraStencilData *pData )
{
KivioPainter * painter;
- KivioShapeData *pShapeData = pShape->shapeData();
+ KivioShapeData *pShapeData = pShape->tqshapeData();
KivioPoint *pPoint, *pNewPoint;
TQPtrList <KivioPoint> *pPointList = pShapeData->pointList();
@@ -262,7 +262,7 @@ void KivioSMLConnector::paint( KivioIntraStencilData *pData )
}
// Build shape up from m_pConnectorPoints
TQPtrList <KivioPoint> *pNewPoints = new TQPtrList<KivioPoint>;
@@ -314,7 +314,7 @@ bool KivioSMLConnector::saveCustom( TQDomElement &e, TQDomDocument &doc )
kdDebug(43000) << "Save custom " << endl;
e.appendChild( saveArrowHeads( doc ) );
- //TQDomElement type = m_shape->saveXML(doc);
+ //TQDomElement type = m_tqshape->saveXML(doc);
KivioConnectorPoint *p = m_PointList.first();
while ( p )
{
@@ -341,7 +341,7 @@ bool KivioSMLConnector::loadCustom( const TQDomElement &e )
}
else if ( name == "KivioShape" )
{
- //m_shape->loadXML(node.toElement());
+ //m_tqshape->loadXML(node.toElement());
TQDomNode pts = node.firstChild();
while ( !pts.isNull() )
{
@@ -96,9 +96,9 @@ KivioSMLConnector::KivioSMLConnector( const TQString &name )
// This is a stencil of type connector
setType( kstConnector );
- // We only have one shape, an open path.
- //m_shape = new KivioShape();
- //m_shape->shapeData() ->setShapeType( KivioShapeData::kstOpenPath );
+ // We only have one tqshape, an open path.
+ //m_tqshape = new KivioShape();
+ //m_tqshape->tqshapeData() ->setShapeType( KivioShapeData::kstOpenPath );
loadPath( name );
}
@@ -262,7 +262,7 @@ void KivioSMLConnector::paint( KivioIntraStencilData *pData )
}
- // Build shape up from m_pConnectorPoints
+ // Build tqshape up from m_pConnectorPoints
TQPtrList <KivioPoint> *pNewPoints = new TQPtrList<KivioPoint>;